@@ -6,14 +6,12 @@
 
 #define QT_FEATURE_designer 1
 
-#define QT_FEATURE_distancefieldgenerator 1
+#define QT_FEATURE_distancefieldgenerator -1
 
 #define QT_FEATURE_kmap2qmap 1
 
 #define QT_FEATURE_linguist 1
 
-#define QT_FEATURE_macdeployqt -1
-
 #define QT_FEATURE_pixeltool 1
 
 #define QT_FEATURE_qdbus 1
@@ -26,5 +24,3 @@
 
 #define QT_FEATURE_qtplugininfo 1
 
-#define QT_FEATURE_windeployqt -1
-
